
[![](https://codecov.io/gh/nickderobertis/ufrc/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/ufrc)

#  ufrc

## Overview

Tools for UFRC

## Getting Started

Install `ufrc`:

```
pip install ufrc
```

A simple example:

```python
import ufrc

# Do something with ufrc
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/ufrc/
)

## Author

Created by Nick DeRobertis. MIT License.